searchData={"items":[{"type":"task","title":"mix tempus.gen.postgres.tempus_slot","doc":"Generates a migration to add a composite type called `:tempus_slot`\n  to a Postgres database.\n\nThe `:tempus_slot` type created is a composite type and therefore\n  may not be supported in other databases.","ref":"Mix.Tasks.Tempus.Gen.Postgres.TempusSlot.html"},{"type":"behaviour","title":"Tempus.Ecto.Query.API","doc":"Provides several helpers to query DB for the `Tempus.Slot` type.\n\nUnder the hood it delegates to\n[`Ecto.Query.API.fragment/1`](https://hexdocs.pm/ecto/Ecto.Query.API.html#fragment/1-defining-custom-functions-using-macros-and-fragment),\nbut might be helpful for compile-type sanity check for typos and\nbetter language server support.\n\nIt is also designed to be an implementation-agnostic, meaning one can use\nthese helpers without a necessity to explicitly specify a backing type.\n\nThe default implementation recommends a `Composite` adapter, which is used by default.\nTo use it with, say, `MySQL`, one should implement this behaviour for `MySQL` and declare\nthe implementation as `use Tempus.Ecto.Query.API, adapter: MyImpl.MySQL.Adapter`\n\nAlthough the library provides the MySQL adapter too (`Tempus.Ecto.Query.API.Map.MySQL`,)\nbut it is not actively maintained, so use it on your own.\n\nIf for some reason you use `Map` type with `Postgres`, helpers are still available\nwith `use Tempus.Ecto.Query.API, adapter: Tempus.Ecto.Query.API.Map.Postgres`","ref":"Tempus.Ecto.Query.API.html"},{"type":"macrocallback","title":"Tempus.Ecto.Query.API.slot_from/1","doc":"Native implementation of how to retrieve `from` part of the slot from the DB.\n\nFor `Postgres`, it delegates to the function on the composite type,\n  for other implementation it should return a `Ecto.Query.API.fragment/1`.","ref":"Tempus.Ecto.Query.API.html#c:slot_from/1"},{"type":"macrocallback","title":"Tempus.Ecto.Query.API.slot_to/1","doc":"Native implementation of how to retrieve `to` part of the slot from the DB.\n\nFor `Postgres`, it delegates to the function on the composite type,\n  for other implementation it should return a `Ecto.Query.API.fragment/1`.","ref":"Tempus.Ecto.Query.API.html#c:slot_to/1"},{"type":"macro","title":"Tempus.Ecto.Query.API.started_after/2","doc":"`Ecto.Query.API` helper, allowing to filter records having the same currency.\n\n_Example:_\n\n```elixir\ndt = ~U[2023-01-01 00:00:00Z]\nOccasion\n|> where([o], started_after(o.initial, ^dt))\n|> select([o], o.initial)\n|> Repo.all()\n#⇒ [%Tempus.Slot{from: ~U[2023-04-07 00:00:00Z], to: ~U[2023-04-10 23:59:59.999999Z]}]\n```","ref":"Tempus.Ecto.Query.API.html#started_after/2"},{"type":"module","title":"Tempus.SQL","doc":"The set of functions bringing DB support to `Tempus` library.\n\nStart with adding the `tempus_sql` dependency to your project.\n\n```elixir\ndef deps do\n  [\n    {:tempus_sql, \"~> 0.1\"}\n  ]\nend\n```\n\nGenerate a migration to add a custom type to your Postgres DB.\n\n```sh\n$ mix tempus.gen.postgres.tempus_slot\n```\n\nCreate a schema which would use the type.\n\n```elixir\nschema \"meetings\" do\n  field :name,  :string\n  field :slot,  Tempus.Ecto.Composite.Type\n  timestamps()\nend\n\ndef changeset(meeting, params \\\\ %{}),\n  do: cast(meeting, params, [:slot])\n```\n\nFor custom queries see `Tempus.Ecto.Query.API`.","ref":"Tempus.SQL.html"},{"type":"module","title":"Tempus.Ecto.Composite.Type","doc":"Implements the `Ecto.Type` behaviour for a user-defined\n  [postgres composite type](https://www.postgresql.org/docs/current/rowtypes.html)\n  called `:tempus_slot` to store instances of `Tempus.Slot`.\n\nThis type is preferred over `Tempus.Ecto.Map.Type`\n  unless there is no way to use composite types (e. g. `MySQL` database.)","ref":"Tempus.Ecto.Composite.Type.html"},{"type":"function","title":"Tempus.Ecto.Composite.Type.cast/1","doc":"","ref":"Tempus.Ecto.Composite.Type.html#cast/1"},{"type":"function","title":"Tempus.Ecto.Composite.Type.cast_type/1","doc":"","ref":"Tempus.Ecto.Composite.Type.html#cast_type/1"},{"type":"function","title":"Tempus.Ecto.Composite.Type.embed_as/1","doc":"","ref":"Tempus.Ecto.Composite.Type.html#embed_as/1"},{"type":"function","title":"Tempus.Ecto.Composite.Type.equal?/2","doc":"","ref":"Tempus.Ecto.Composite.Type.html#equal?/2"},{"type":"module","title":"Tempus.Ecto.Map.Type","doc":"Implements `Ecto.Type` behaviour for `Tempus.Slot`,\n  where the underlying schema type is a map.\n\nThis is the required option for databases such as _MySQL_\n  that do not support composite types.","ref":"Tempus.Ecto.Map.Type.html"},{"type":"function","title":"Tempus.Ecto.Map.Type.cast/1","doc":"","ref":"Tempus.Ecto.Map.Type.html#cast/1"},{"type":"function","title":"Tempus.Ecto.Map.Type.cast/2","doc":"","ref":"Tempus.Ecto.Map.Type.html#cast/2"},{"type":"function","title":"Tempus.Ecto.Map.Type.dump/3","doc":"","ref":"Tempus.Ecto.Map.Type.html#dump/3"},{"type":"function","title":"Tempus.Ecto.Map.Type.embed_as/1","doc":"","ref":"Tempus.Ecto.Map.Type.html#embed_as/1"},{"type":"function","title":"Tempus.Ecto.Map.Type.equal?/2","doc":"","ref":"Tempus.Ecto.Map.Type.html#equal?/2"},{"type":"function","title":"Tempus.Ecto.Map.Type.init/1","doc":"","ref":"Tempus.Ecto.Map.Type.html#init/1"},{"type":"function","title":"Tempus.Ecto.Map.Type.load/3","doc":"","ref":"Tempus.Ecto.Map.Type.html#load/3"},{"type":"function","title":"Tempus.Ecto.Map.Type.type/1","doc":"","ref":"Tempus.Ecto.Map.Type.html#type/1"},{"type":"extras","title":"TempusSQL","doc":"# ![TempusSQL](https://raw.githubusercontent.com/am-kantox/tempus_sql/master/stuff/tempus_sql-48x48.png) TempusSQL    [![Kantox ❤ OSS](https://img.shields.io/badge/❤-kantox_oss-informational.svg)](https://kantox.com/)  ![Test](https://github.com/am-kantox/tempus_sql/workflows/Test/badge.svg)  ![Dialyzer](https://github.com/am-kantox/tempus_sql/workflows/Dialyzer/badge.svg)\n\n**Ecto/SQL backend to use with `Tempus` library**","ref":"readme.html"},{"type":"extras","title":"Installation - TempusSQL","doc":"```elixir\ndef deps do\n  [\n    {:tempus_sql, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Changelog - TempusSQL","doc":"- **`0.10.0`** — version numbers correspond to `Tempus` itself\n- **`0.1.0`** — initial version, `Tempus.Ecto.Query.API.started_after/2`\n\n## [Documentation](https://hexdocs.pm/tempus_sql)","ref":"readme.html#changelog"}],"content_type":"text/markdown"}